/***************************************************************************
 $RCSfile$
                             -------------------
    cvs         : $Id: categoryview.h 301 2005-08-31 05:24:20Z aquamaniac $
    begin       : Mon Mar 01 2004
    copyright   : (C) 2004 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/



#ifndef KBANKING_CATEGORYVIEW_H
#define KBANKING_CATEGORYVIEW_H


#include "accountview.ui.h"


class CategoryView;
class KBanking;
class QPushButton;

#include "categorywidget.h"


class CategoryView: public CategoryWidget {
  Q_OBJECT
public:
  CategoryView(KBanking *kb,
               QWidget* parent=0, const char* name=0, WFlags fl=0);
  ~CategoryView();

  bool init();
  bool fini();

private:
  KBanking *_app;
  QPushButton *_calculateButton;
  QPushButton *_calculateAllButton;
  QPushButton *_transactionsButton;
protected slots:
  void slotUpdated();

  void slotTransactions();
  void slotCalc();
  void slotCalcAll();

};










#endif /* KBANKING_CATEGORYVIEW_H */



